Documentation
¶
Overview ¶
This is an extremely minimal subset of github.com/dagger/otel-go so we can avoid depending on everything else. Critically we have to avoid pre-1.0 dependencies like the OTel logging SDK.
Index ¶
Constants ¶
const CLIVersion = "0.20.2"
Variables ¶
var ( // Only modified by tests, not changeable by outside users due to being in // an internal package OverrideCLIArchiveURL string OverrideChecksumsURL string )
Functions ¶
This section is empty.
Types ¶
type ConnectParams ¶
type EngineConn ¶
func FromDownloadedCLI ¶
func FromDownloadedCLI(ctx context.Context, cfg *Config) (EngineConn, error)
func FromLocalCLI ¶
func FromSessionEnv ¶
func FromSessionEnv() (EngineConn, bool, error)
Click to show internal directories.
Click to hide internal directories.